@@ -1,4 +1,5 @@
 from .PostgresReader import PostgresReader
+from .SQLServerReader import SQLServerReader
 from ..Types import POSTGRES, SQLSERVER
 
 
@@ -6,4 +7,4 @@ def factory(s3_credentials, struct, migrator_redshift_connector):
     if migrator_redshift_connector.source_conn_type == POSTGRES:
       return PostgresReader(s3_credentials, struct, migrator_redshift_connector)
     elif migrator_redshift_connector.source_conn_type == SQLSERVER:
-      return None
\ No newline at end of file
+      return SQLServerReader(s3_credentials, struct, migrator_redshift_connector)
\ No newline at end of file
