@@ -20,7 +20,8 @@ class WriterNonCDC(GenericWriter, WriterInterface):
         try:
             self.create_table_temp_target_relation()
             self.copy_data_to_target(url, self.temp_target_relation)
-            self.migrator_redshift_connector.target_conn.commit()
+
+            self.migrator_redshift_connector.target_conn.autocommit = False
 
             if self.is_upsert is True and load_option != FULL:
                 self.delete_using_temp_target_from_target()
@@ -30,11 +31,10 @@ class WriterNonCDC(GenericWriter, WriterInterface):
             self.insert_data_from_temp_to_target()
 
             self.migrator_redshift_connector.target_conn.commit()
+            self.migrator_redshift_connector.target_conn.autocommit = True
 
             self.drop_table_temp_target_relation()
 
-            self.migrator_redshift_connector.target_conn.commit()
-
             self.delete_on_tmp_s3(url)
         except Exception as e:
             self.delete_on_tmp_s3(url)
